源代码 (豆瓣)
Description: 源代码电影简介和剧情介绍,源代码影评、图片、预告片、影讯、论坛、在线购票
Keywords: 源代码,Source Code,源代码影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.207豆瓣电影Top250

# 源代码 Source Code (2011)

导演: 邓肯·琼斯
编剧: 本·雷普利
主演: 杰克·吉伦哈尔 / 维拉·法米加 / 米歇尔·莫纳汉 / 杰弗里·怀特 / 拉塞尔·皮特斯 / 詹姆斯·A·伍兹 / 迈克尔·阿登 / 乔·柯布登 / 卡斯·安瓦尔
类型: 科幻 / 悬疑 / 惊悚
制片国家/地区: 美国 / 加拿大
语言: 英语
上映日期: 2011-08-30(中国大陆) / 2011-03-11(西南偏南电影节) / 2011-04-01(美国)
片长: 93分钟
又名: 启动原始码(台) / 危机解密(港)
IMDb: tt0945513
豆瓣评分
引用
8.5
797586人评价
5星
39.6%
4星
47.8%
3星
11.9%
2星
0.6%
1星
0.1%
好于 97% 科幻片
好于 97% 悬疑片
想看 看过
评价:
推荐

## 源代码的剧情简介 · · · · · ·

在阿富汗执行任务的美国空军飞行员科特史蒂文斯上尉（杰克·吉伦哈尔 Jake Gyllenhaal 饰）突然惊醒，发现自己在一辆高速行驶的列车上，而他的身边坐着一个素不相识的女子克里斯蒂安（米歇尔·莫娜汉 Michelle Monaghan 饰）正在与自己讲话。科尔不知自己为什么会在这辆车上，而且他发现自己居然是以另一个人的身份存在，正当他迷惑不解的时候，列车上忽然发生爆炸……
科特又一次惊醒，发现自己身处一个密闭的太空仓里，有一位女军官古德温（维拉·法米加 Vera Farmiga 饰）正在通过视频和自己对话，并要求自己报告列车上发生的事情。一头雾水的科特还没搞明白是怎么回事时，他又一次被送上那辆列车。这次之后，科特终于明白自己在执行一件任务，负责调察芝加哥火车爆炸案找到恐怖份子并查出他的下一个目标。科特被一次又一次的送上那辆高速列车，每次只有八分钟... (展开全部) 在阿富汗执行任务的美国空军飞行员科特史蒂文斯上尉（杰克·吉伦哈尔 Jake Gyllenhaal 饰）突然惊醒，发现自己在一辆高速行驶的列车上，而他的身边坐着一个素不相识的女子克里斯蒂安（米歇尔·莫娜汉 Michelle Monaghan 饰）正在与自己讲话。科尔不知自己为什么会在这辆车上，而且他发现自己居然是以另一个人的身份存在，正当他迷惑不解的时候，列车上忽然发生爆炸……
科特又一次惊醒，发现自己身处一个密闭的太空仓里，有一位女军官古德温（维拉·法米加 Vera Farmiga 饰）正在通过视频和自己对话，并要求自己报告列车上发生的事情。一头雾水的科特还没搞明白是怎么回事时，他又一次被送上那辆列车。这次之后，科特终于明白自己在执行一件任务，负责调察芝加哥火车爆炸案找到恐怖份子并查出他的下一个目标。科特被一次又一次的送上那辆高速列车，每次只有八分钟的时间调察，调察过程中，科特发现自己已在一周前去世，原来他正在参与是一项“脑波原代码”的秘密任务，这项任务通过已经死亡的科特尚未完全死亡的脑细胞影像来还原事件，调查事情的真相。最终，科特顺利完成了任务，但是他却决定再一次返回列车，拯救列车上那些无辜的生命…… ©豆瓣

## 源代码的演职员 · · · · · · ( 全部 20 )

- 邓肯·琼斯 导演
- 杰克·吉伦哈尔 演员
- 维拉·法米加 演员
- 米歇尔·莫纳汉 演员
- 杰弗里·怀特 演员
- 拉塞尔·皮特斯 演员

## 源代码的视频和图片 · · · · · · ( 预告片6 | 视频评论1 · 添加 | 图片794 · 添加 )

## 源代码的获奖情况 · · · · · · ( 全部 )

- 第2届豆瓣电影鑫像奖
- 鑫豆单元 最佳影片(外语)(提名)

- 第2届豆瓣电影鑫像奖
- 鑫豆单元 最佳导演(外语)(提名)
- 邓肯·琼斯

## 喜欢这部电影的人也喜欢 · · · · · ·

  盗梦空间

  黑客帝国

  这个男人来自地球

  蝴蝶效应

  致命魔术

  阿凡达

  终结者2：审判日

  第九区

  明日边缘

  彗星来的那一夜

我要写短评

## 源代码的短评 · · · · · · ( 全部 164713 条 )

热门 / 最新 / 好友

### 3994 有用 seren 看过 2011-04-08 07:09:01

平行世界理论一定是真的，我坚定不移的相信着

### 8424 有用 daparo 看过 2011-06-19 02:08:54

後面有延續的結局才是perfect！！！而不是傻逼的在那個kiss的時候結束！

### 1255 有用 MOJO 看过 2011-06-26 22:02:05

每当我想起，在另一个时间与空间里，我与你有着截然不同的故事时，我便释然此时此刻你与我的狭路相逢。

### 3279 有用 易老邪 看过 2011-07-13 20:26:27

居然有那么多人认为《源代码》最完美的结局应该是定格在最后那一吻上，由此可见，真要这样结尾够有多么的恶俗不堪啊。

### 1860 有用 ParasItE 看过 2011-04-03 13:19:30

如果结局停在那一吻我就给四星半了。

> 更多短评 164713条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 源代码的影评 · · · · · · ( 全部 2566 条 )

热门 / 最新 / 好友
时间地理学家 2011-04-05 10:05:12

## 影片情节再现，难点解释（全剧剧透，渗入！）

备注：因为看的是英文，所以情节可能在细节上有所出入。部分情节仅仅是笔者的个人理解，如有纰漏，敬请更正。 注意，此文是全剧剧透！而且听说有可能在中国上映，所以没有看的朋友渗入！ -------------------------------------------------------------------------------... (展开)
4120 559 1046回应 收起
菠萝 2011-07-03 11:02:14

## 对电影最后数分钟以及源代码系统的理解

这篇影评可能有剧透

以下内容提出一种我看完电影后的假设且已完全剧透： 基本介绍， 柯尔特史蒂文：主角，美军上尉 肖恩范翠思：历史教师，主角对应的源代码穿越者 古德温：负责与主角联络的人 克里斯蒂娜：肖恩的朋友，坐在主角穿越点旁边 拉特里奇博士：研发源代码系统的人 在电影中可见... (展开)
3536 162 583回应 收起
大大大大西瓜 2011-06-12 23:59:22

## 不懂结局的来看

这篇影评可能有剧透

刚看完《源代码》，对于结局纠结了半天。现在仅对结局做一个解释，希望能给大家对于理解影片有所帮助。 首先简述一下影片的故事情节：一位名叫柯尔特·史蒂文的上尉，某日当他醒来时发现自己正在一辆前往芝加哥的火车上，而他在火车的主要目的就是要找到是谁把炸弹放在了火车上... (展开)
1602 228 362回应 收起
克罗希尔 2011-09-04 10:36:30

## 《源代码》告诉我们的三件事

1、为国家效力，死一次就够了；——影片中斯蒂文森上尉的原话； 2、如果你为他人做出了牺牲和贡献，那么你理应得到回报。——很多豆油都对本片貌似有点多余的结局感到遗憾，但是让主角们在源代码的世界里继续活下去，才是符合人性和符合编剧导演的本意的。给他人带来生命的人... (展开)
334 18 27回应 收起
doodlebug 2011-04-21 17:28:11

## 不仅仅是个8分钟直到型循环 | It's gonna be OK.

也许生活就是需要耳边有一个声音不断提醒"it's gonna be OK"。结尾的设置真不错，像是Prison Break里的"just have a lil faith"，又或者Inception里的"take a leap of faith"。老美真是热爱制造若隐若现若有似无的那丝信念。 虽说此片感情戏的部分如此烂俗 - 1> 以自己朋友的... (展开)
294 68 123回应 收起
宋小卡 2011-09-01 13:33:28

## 给中国科幻电影指条明路——《源代码》的省钱之道(技术贴！)

大卫·鲍伊的导演儿子邓肯·琼斯用3200万拍出了《源代码》，让全世界为之交口，而我们却把1个亿白白扔给《哈利·波特》的特效团队，只为做在《寻龙夺宝》里做一条外国人从没见过的“神龙”。这样的反差是否值得我们为之反思？《源代码》的省钱之道是否能给一片空白的中国科幻电... (展开)
258 34 52回应 收起
赵烟侠 2011-07-21 22:28:07

## 用四句话讲明白狗血剧情，小心被雷到

这篇影评可能有剧透

男主角：Colter，网瘾严重的残疾军人，在网游中的ID叫Sean 女一号：Christina，网游中的一名NPC 女二号：Goodwin，网游客服 反派一：Rutledge，网吧老板 反派二：Derek，网游中的BOSS 地点：一个叫“COAC-N”的网吧 Colter是一名职业代练，正在“COAC-N”网吧玩一个叫“源代码... (展开)
240 34 22回应 收起
朱朱朱古力♥ 2011-04-02 11:21:12

## 如果一切停止在那一吻

这篇影评可能有剧透

那么Jake在现实和source code中都正式死去. 他在现实中救了数以万计的美国公民,在精神世界里也至少留住了最美丽的一刻.时间静止的画面里都是人们的笑脸, 没有冷漠没有争端,Jake解了与父亲的心结,和女主甜蜜拥吻. 一个军人,没有遗憾带着尊严死去. 这是Jake的初衷. 道德与人性压... (展开)
208 112 256回应 收起

> 更多影评 2566篇

添加新讨论

## 讨论区 · · · · · ·

我发现了《源代码》的致命漏洞。。。 | 来自HelloIndra | 21 回应 | 2022-11-21 13:32:03
所以肖恩就这么被男主夺舍了？ | 来自Caulfield | 16 回应 | 2022-11-21 13:25:25
合理怀疑！这一切都是教授的阴谋～ | 来自风起于青萍之末 | 3 回应 | 2022-11-13 16:43:31
缸中之脑 | 来自椰椰 |  | 2022-11-08 19:52:20
首先应该把重点放在下车的人吧？ | 来自鸿昊 |  | 2022-11-02 22:15:00

> 去这部影片的讨论区（全部537条）

## 关于《源代码》的问题 · · · · · · ( 全部45个 )

- 最后8分钟过去了，切断电源后，为什么科特能在虚拟世界中活下去，博士想要阻止什么？ 11人回答
- 男主进入平行世界后历史老师去哪里了？ 23人回答

> 全部45个问题

## 在哪儿看这部电影 · · · · · ·

- 爱奇艺视频 VIP免费观看
- 西瓜视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- 2011 豆瓣电影【口碑榜】 (影志)
- 数学、物理学生可能感兴趣的电影、纪录片 (傑)
- 2011新电影（这些，可以期待） (桃桃林林)
- 曾经关于时空的豆列 (L.L)
- 剧情扣人、故事性强、不闷的好电影 (影志)

## 谁在看这部电影 · · · · · ·

- VOCCO
  1分钟前 看过
- 沉默是最好的
  1分钟前 看过
- 豆友O4WfE_FJiI
  5分钟前 看过

1174783人看过 / 229547人想看

订阅源代码的评论:
feed: rss 2.0